summaryrefslogtreecommitdiff
path: root/src/timefns.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/timefns.c')
-rw-r--r--src/timefns.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/timefns.c b/src/timefns.c
index 5beeaf57a25..514fa24f8b9 100644
--- a/src/timefns.c
+++ b/src/timefns.c
@@ -1133,7 +1133,7 @@ or (if you need time as a string) `format-time-string'. */)
determine how many bytes would be written, use NULL for S and
((size_t) -1) for MAXSIZE.
- This function behaves like nstrftime, except it allows null
+ This function behaves like nstrftime, except it allows NUL
bytes in FORMAT and it does not support nanoseconds. */
static size_t
emacs_nmemftime (char *s, size_t maxsize, const char *format,
@@ -1141,8 +1141,8 @@ emacs_nmemftime (char *s, size_t maxsize, const char *format,
{
size_t total = 0;
- /* Loop through all the null-terminated strings in the format
- argument. Normally there's just one null-terminated string, but
+ /* Loop through all the NUL-terminated strings in the format
+ argument. Normally there's just one NUL-terminated string, but
there can be arbitrarily many, concatenated together, if the
format contains '\0' bytes. nstrftime stops at the first
'\0' byte so we must invoke it separately for each such string. */